You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@struts.apache.org by sc...@apache.org on 2005/11/14 19:22:55 UTC

svn commit: r344176 - /struts/shale/trunk/core-library/src/java/org/apache/shale/faces/ShaleApplicationFilter.java

Author: schof
Date: Mon Nov 14 10:22:48 2005
New Revision: 344176

URL: http://svn.apache.org/viewcvs?rev=344176&view=rev
Log:
Make sure to cleanup the stored request attribute when exiting ShaleApplicationFilter due to a "true" result in the preprocess command.

Modified:
    struts/shale/trunk/core-library/src/java/org/apache/shale/faces/ShaleApplicationFilter.java

Modified: struts/shale/trunk/core-library/src/java/org/apache/shale/faces/ShaleApplicationFilter.java
URL: http://svn.apache.org/viewcvs/struts/shale/trunk/core-library/src/java/org/apache/shale/faces/ShaleApplicationFilter.java?rev=344176&r1=344175&r2=344176&view=diff
==============================================================================
--- struts/shale/trunk/core-library/src/java/org/apache/shale/faces/ShaleApplicationFilter.java (original)
+++ struts/shale/trunk/core-library/src/java/org/apache/shale/faces/ShaleApplicationFilter.java Mon Nov 14 10:22:48 2005
@@ -271,7 +271,10 @@
               throw new ServletException(e);
           }
           if (result) {
-              return; // Bypass calling the remainder of the application
+              // Clean up the stored request attribute
+              request.removeAttribute(CONTEXT_ATTR);              
+              // Bypass calling the remainder of the application              
+              return;
           }
       }
 



---------------------------------------------------------------------
To unsubscribe, e-mail: dev-unsubscribe@struts.apache.org
For additional commands, e-mail: dev-help@struts.apache.org